@@ -36,11 +36,11 @@ class mTodos(object):
 
   __pretty_app_name__ = "mTodos"
   __app_name__ = "mTodos"
-  __version__ = "0.0.1"
+  __version__ = "0.0.2"
   __context__ = "net.khertan.mtodos"
 
   _glade_files = [
-    'ui/mtodos.glade',
+    '/usr/lib/mtodos/ui/mtodos.glade',
   ]
 
   def __init__(self,app,context):
@@ -148,7 +148,7 @@ class mTodos(object):
   def _open_search_diag(self,widget):
     self.search_dialog = self._widgetTree.get_widget("dSearchDiag")
     self.search_dialog.run()
-    
+
   def _cancel_search_diag(self,widget):
     self.search_dialog.hide()
 
@@ -157,7 +157,6 @@ class mTodos(object):
     self.search_dialog.hide()
     self._search_todoslist_bg(searched_text)
 
-
   def refresh(self):
     self._load_todoslist_bg()
 #   gtk.gdk.threads_enter()
@@ -496,7 +495,6 @@ class mTodos(object):
     self._todos_label_process = threading.Thread(target=self._set_label)
     self._todos_label_process.start()
 
-
   def _set_label(self):
     gtk.gdk.threads_enter()
     self._now_label.set_markup('<b>Now</b>\n'+str(len(mtodos_framework.TodosList().get_now_todos()))+' tasks')
